import unittest

import sys

if sys.version_info >= (2, 6):  # no PKG-INFO installed in earlier Pythons

    class InstalledTests(unittest.TestCase):

        def _getTargetClass(self):
            from pkginfo.installed import Installed
            return Installed

        def _makeOne(self, filename=None, metadata_version=None):
            if metadata_version is not None:
                return self._getTargetClass()(filename, metadata_version)
            return self._getTargetClass()(filename)

        def test_ctor_w_package_no___file__(self):
            import sys
            import warnings
            old_filters = warnings.filters[:]
            warnings.filterwarnings('ignore')
            try:
                installed = self._makeOne(sys)
                self.assertEqual(installed.package, sys)
                self.assertEqual(installed.package_name, 'sys')
                self.assertEqual(installed.metadata_version, None)
            finally:
                warnings.filters[:] = old_filters

        def test_ctor_w_package(self):
            import pkginfo
            from pkginfo.tests import _checkSample
            installed = self._makeOne(pkginfo)
            self.assertEqual(installed.package, pkginfo)
            self.assertEqual(installed.package_name, 'pkginfo')
            self.assertEqual(installed.metadata_version, '1.0')
            _checkSample(self, installed)

        def test_ctor_w_package_no_PKG_INFO(self):
            import types
            import warnings
            old_filters = warnings.filters[:]
            warnings.filterwarnings('ignore')
            try:
                installed = self._makeOne(types)
                self.assertEqual(installed.package, types)
                self.assertEqual(installed.package_name, 'types')
                self.assertEqual(installed.metadata_version, None)
            finally:
                warnings.filters[:] = old_filters

        def test_ctor_w_package_and_metadata_version(self):
            import pkginfo
            from pkginfo.tests import _checkSample
            installed = self._makeOne(pkginfo, metadata_version='1.2')
            self.assertEqual(installed.metadata_version, '1.2')
            self.assertEqual(installed.package.__name__, 'pkginfo')
            _checkSample(self, installed)

        def test_ctor_w_name(self):
            import pkginfo
            from pkginfo.tests import _checkSample
            installed = self._makeOne('pkginfo')
            self.assertEqual(installed.metadata_version, '1.0')
            self.assertEqual(installed.package, pkginfo)
            self.assertEqual(installed.package_name, 'pkginfo')
            _checkSample(self, installed)

        def test_ctor_w_name_and_metadata_version(self):
            import pkginfo
            from pkginfo.tests import _checkSample
            installed = self._makeOne('pkginfo', metadata_version='1.2')
            self.assertEqual(installed.metadata_version, '1.2')
            self.assertEqual(installed.package, pkginfo)
            self.assertEqual(installed.package_name, 'pkginfo')
            _checkSample(self, installed)

        def test_ctor_w_invalid_name(self):
            import warnings
            old_filters = warnings.filters[:]
            warnings.filterwarnings('ignore')
            try:
                installed = self._makeOne('nonesuch')
                self.assertEqual(installed.package, None)
                self.assertEqual(installed.package_name, 'nonesuch')
                self.assertEqual(installed.metadata_version, None)
            finally:
                warnings.filters[:] = old_filters

        def test_ctor_w_egg_info_as_file(self):
            import pkginfo.tests.funny
            installed = self._makeOne('pkginfo.tests.funny')
            self.assertEqual(installed.metadata_version, '1.0')
            self.assertEqual(installed.package, pkginfo.tests.funny)
            self.assertEqual(installed.package_name, 'pkginfo.tests.funny')



from pkginfo.bdist import BDist
from pkginfo.develop import Develop
from pkginfo.distribution import Distribution
from pkginfo.index import Index
from pkginfo.installed import Installed
from pkginfo.sdist import SDist
from pkginfo.utils import get_metadata



# requirements
import pkg_resources

def additional_tests():
    import doctest
    import unittest
    return unittest.TestSuite((
        doctest.DocFileSuite('../../docs/index.rst',
                                module_relative=True),
        doctest.DocFileSuite('../../docs/distributions.rst',
                                module_relative=True),
        doctest.DocFileSuite('../../docs/metadata.rst',
                                module_relative=True),
        doctest.DocFileSuite('../../docs/indexes.rst',
                                module_relative=True),
    ))


def _checkSample(testcase, installed):
    version = pkg_resources.require('pkginfo')[0].version
    testcase.assertEqual(installed.name, 'pkginfo')
    testcase.assertEqual(installed.version, version)
    testcase.assertEqual(installed.keywords,
                        'distribution sdist installed metadata' )
    testcase.assertEqual(list(installed.supported_platforms), [])

def _checkClassifiers(testcase, installed):
    testcase.assertEqual(list(installed.classifiers),
                         [
      'Intended Audience :: Developers',
      'License :: OSI Approved :: Python Software Foundation License',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 2',
      'Topic :: Software Development :: Libraries :: Python Modules',
      'Topic :: System :: Software Distribution',
    ])



import glob
import os
import sys
import warnings

from pkginfo.distribution import Distribution

class Develop(Distribution):

    def __init__(self, path, metadata_version=None):
        self.path = os.path.abspath(
                        os.path.normpath(
                            os.path.expanduser(path)))
        self.metadata_version = metadata_version
        self.extractMetadata()

    def read(self):
        candidates = [self.path]
        candidates.extend(glob.glob(os.path.join(self.path, '*.egg-info')))
        candidates.extend(glob.glob(os.path.join(self.path, 'EGG-INFO')))
        for candidate in candidates:
            if os.path.isdir(candidate):
                path = os.path.join(candidate, 'PKG-INFO')
                if os.path.exists(path):
                    return open(path).read()
        warnings.warn('No PKG-INFO found for path: %s' % self.path)
